﻿using System;
using System.Collections.ObjectModel;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using Infragistics.Controls.Charts;

namespace InfragisticsXamDataChartTest
{
    public partial class MainPage : UserControl
    {
        public ObservableCollection<double> TimeSinceStart { get; set; }
        public ObservableCollection<double> Values { get; set; }
        public NumericYAxis myYAxis;
        public CategoryDateTimeXAxis myXAxis;
        public XamDataChart dataChart;
        public MainPage()
        {
            DataContext = this;

            InitializeComponent();

            Loaded += OnLoaded;
        }

        private const double PointsGetHiddenWidth = 584;

        private void OnLoaded(object sender, RoutedEventArgs routedEventArgs)
        {
            const int numberOfPointsToGenerate = 50;
            const int sawWaveAmplitude = 10;
            TimeSinceStart =
                new ObservableCollection<double>(Enumerable.Range(0, numberOfPointsToGenerate).Select(i => (double) i));

            var r = new Random(0);
            Values = new ObservableCollection<double>();
            for (var z = 0; z < TimeSinceStart.Count; z++)
            {
                Values.Add(0);
            }

            dataChart = new XamDataChart()
            {
                HorizontalZoomable = true,
                VerticalZoomable = true,
            };

            
            myXAxis = new CategoryDateTimeXAxis()
            {
                MinimumValue = new DateTime((long)(TimeSinceStart.First())),
                MaximumValue = new DateTime((long)(TimeSinceStart.Last())),
                ItemsSource = TimeSinceStart.Select(n => new DateTime((long)(n))),
                DateTimeMemberPath = "",
            };
            dataChart.Axes.Add(myXAxis);

            myYAxis = new NumericYAxis()
            {
                MinimumValue = -2000,
                MaximumValue = 2000,
            };
            dataChart.Axes.Add(myYAxis);

            LayoutRoot.Children.Add(dataChart);

            dataChart.Series.Add(new SplineSeries()
            {
                ItemsSource = Values,
                XAxis = myXAxis,
                YAxis = myYAxis,
                ValueMemberPath = "",
                MarkerType = MarkerType.Circle,
            });

            Values = new ObservableCollection<double>();
            for (var z = 0; z < TimeSinceStart.Count; z++)
            {
                Values.Add(1000);
            }
            dataChart.Series.Add(new SplineSeries()
            {
                ItemsSource = Values,
                XAxis = myXAxis,
                YAxis = myYAxis,
                ValueMemberPath = "",
                MarkerType = MarkerType.None,
                MarkerTemplate = (DataTemplate)Resources["VerticalLine"]
            });

        }

        private double lastWidth;
        private void Button_Click(object sender, RoutedEventArgs e)
        {
            lastWidth = Application.Current.MainWindow.Width;
            if (Application.Current.MainWindow.Width != PointsGetHiddenWidth)
            {
                Application.Current.MainWindow.Width = PointsGetHiddenWidth;
            }
            else
            {
                Application.Current.MainWindow.Width = lastWidth;
            }
        }
    }
}
